==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningRadialMarkerStyleEventArgs", function () { return new AssigningRadialMarkerStyleEventArgsDescription(); });
        a.t("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningRadialMarkerStyleEventArgs", function () { return new AssigningRadialMarkerStyleEventArgsDescription(); });
        a.z("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialMarkerStyleEventArgsDescriptionMetadata };
